@@ -42,7 +42,7 @@ import logging
 from glob import glob
 from fnmatch import fnmatch
 from six.moves.configparser import ConfigParser
-import xml.etree.cElementTree as ET
+import xml.etree.ElementTree as ET
 from six.moves.html_parser import HTMLParser
 
 from sugar3 import env
@@ -629,9 +629,9 @@ def start():
     source_dir = os.path.abspath(os.path.dirname(sys.argv[0]))
     config = Config(source_dir)
 
-    try:
-        globals()['cmd_' + options.command](config, options)
-    except (KeyError, IndexError):
+    if 'cmd_' + (options.command or '') in globals():
+        globals()['cmd_' + (options.command or '')](config, options)
+    else:
         parser.print_help()
 
 
