@@ -21,8 +21,6 @@ STABLE.
 """
 
 import logging
-
-from gi.repository import GObject
 import dbus
 import dbus.exceptions
 from dbus import PROPERTIES_IFACE
@@ -31,16 +29,20 @@ from sugar3.presence.buddy import Buddy, Owner
 from sugar3.presence.activity import Activity
 from sugar3.presence.connectionmanager import get_connection_manager
 
-from telepathy.interfaces import ACCOUNT, \
-    ACCOUNT_MANAGER, \
-    CONNECTION
-from telepathy.constants import HANDLE_TYPE_CONTACT
-
+from gi.repository import GObject
+from gi.repository import TelepathyGLib
 
 _logger = logging.getLogger('sugar3.presence.presenceservice')
 
-ACCOUNT_MANAGER_SERVICE = 'org.freedesktop.Telepathy.AccountManager'
-ACCOUNT_MANAGER_PATH = '/org/freedesktop/Telepathy/AccountManager'
+ACCOUNT_MANAGER_SERVICE = TelepathyGLib.ACCOUNT_MANAGER_BUS_NAME
+ACCOUNT_MANAGER_PATH = TelepathyGLib.ACCOUNT_MANAGER_OBJECT_PATH
+ACCOUNT_MANAGER = TelepathyGLib.IFACE_ACCOUNT_MANAGER
+
+ACCOUNT = TelepathyGLib.IFACE_ACCOUNT
+
+HANDLE_TYPE_CONTACT = TelepathyGLib.HandleType.CONTACT
+
+CONNECTION = TelepathyGLib.IFACE_CONNECTION
 
 CONN_INTERFACE_ACTIVITY_PROPERTIES = 'org.laptop.Telepathy.ActivityProperties'
 
@@ -78,7 +80,8 @@ class PresenceService(GObject.GObject):
             connection_manager = get_connection_manager()
             connections_per_account = \
                 connection_manager.get_connections_per_account()
-            for account_path, connection in connections_per_account.items():
+            for account_path, connection in list(
+                    connections_per_account.items()):
                 if not connection.connected:
                     continue
                 logging.debug('Calling GetActivity on %s' % account_path)
@@ -86,13 +89,13 @@ class PresenceService(GObject.GObject):
                     room_handle = connection.connection.GetActivity(
                         activity_id,
                         dbus_interface=CONN_INTERFACE_ACTIVITY_PROPERTIES)
-                except dbus.exceptions.DBusException, e:
+                except dbus.exceptions.DBusException as e:
                     name = 'org.freedesktop.Telepathy.Error.NotAvailable'
                     if e.get_dbus_name() == name:
                         logging.debug("There's no shared activity with the id "
                                       "%s" % activity_id)
                     elif e.get_dbus_name() == \
-                         'org.freedesktop.DBus.Error.UnknownMethod':
+                            'org.freedesktop.DBus.Error.UnknownMethod':
                         logging.warning(
                             'Telepathy Account %r does not support '
                             'Sugar collaboration', account_path)
